@@ -40,9 +40,9 @@ case "$1" in
             mv "$VAR_DIR/$USER_DB" "$VAR_DIR/${USER_DB}2"
             echo .dump| sqlite "$VAR_DIR/${USER_DB}2" | sqlite3 "$VAR_DIR/$USER_DB"
         fi
-        sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/doc/benno-web/contrib/db-create.sql 2>/dev/null
+        sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/benno-web/db-create.sql 2>/dev/null
         #
-        sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/doc/benno-web/contrib/db-update_2.0.1.sql 2>/dev/null
+        sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/benno-web/db-update_2.0.1.sql 2>/dev/null
         #
         set -e
 
