@@ -67,22 +67,32 @@ foreach ($EMail->getAttachments() as $Attachment) {
 }
 $MailObject->attachments= $atm_list;
 
+$default_contenttype = $App->getConfig('DEFAULT_CONTENTYPE','text/html');
 try {
-    $MailObject->body       = nl2br($EMail->getBody());
+    $body_content = $EMail->getBody($default_contenttype);
+    $body_type = $default_contenttype;
 }
 catch (Exception $e) {
-    if ($e->getMessage() == 'CONTENT_HTML') {
-        $MailObject->body   = $EMail->getBody('text/html');
-        $MailObject->bodytype = 'text/html';
-    }
-    else {
-        $App->log('Cannot fetch email body: '.$e->getMessage(),1,'a_showEmail');
+    if ($e->getMessage() == 'NO_CONTENT') {
+        if ($default_contenttype == 'text/html') {
+            $body_type = 'text/plain';
+        }
+        else {
+            $body_type = 'text/html';
+        }
     }
 }
+try {
+    $body_content = $EMail->getBody($body_type);
+}
+catch (Exception $e) {
+    $App->log('Cannot fetch email body: '.$e->getMessage(),1,'a_showEmail');
+}
 
 $mailDate = $EMail->getDate();
-$MailObject->date       = strftime($LOCALE['dateformat'],$mailDate);
-$MailObject->time       = strftime($LOCALE['timeformat'],$mailDate);
+$MailObject->setDate(strftime($LOCALE['dateformat'],$mailDate));
+$MailObject->setTime(strftime($LOCALE['timeformat'],$mailDate));
+$MailObject->setBody($body_content,$body_type);
 
 if ($errorMsg) {
     $MailObject->setError('ID_NOT_FOUND');
