@@ -55,7 +55,9 @@ catch (Exception $e) {
 }
 
 if ($body_type == 'text/html') {
-    $body_content = preg_replace('/^.*?<body>(.*?)<\/body>.*$/','$1',$body_content);
+    $body_content = preg_replace('/<html[^>]*>(.*?)<\/html>/is','${1}',$body_content);
+    $body_content = preg_replace('/<body[^>]*>(.*?)<\/body>/is','${1}',$body_content);
+    $App->assign('HTMLBODY',true);
 }
 
 $App->assign('EMPTY',true);
